@@ -1,3 +1,3 @@
 from pilkit.processors.crop import Crop, SmartCrop, TrimBorderColor
 
-__all__ = ['Crop', 'TrimBorderColor', 'SmartCrop']
+__all__ = ["Crop", "TrimBorderColor", "SmartCrop"]
